@@ -120,10 +120,12 @@ class UTextResult(unittest.TextTestResult):
 
     def addError(self, test, err):
         super(unittest.TextTestResult, self).addFailure(test, err)
+        # if self.show_progress_bar:
         self.cc_terminate(success=False)
 
     def addFailure(self, test, err):
         super(unittest.TextTestResult, self).addFailure(test, err)
+        # if self.show_progress_bar:
         self.cc_terminate(success=False)
 
     def addSuccess(self, test: unittest.case.TestCase) -> None:
@@ -173,19 +175,12 @@ class UTextResult(unittest.TextTestResult):
             # For unittest framework where getDescription may return None.
             item_title = self.getDescription(test)
         self.item_title_print = " * q%i.%i) %s" % (UTextResult.number + 1, self.testsRun, item_title)
-        # estimated_time = 10
-
-        # if self._previousTestClass == None:
-        #     print("No prev. test class. ")
         if self.show_progress_bar or True:
             estimated_time = test.__class__._cache.get(((name, test._testMethodName), 'time'), 100) if hasattr(test.__class__, '_cache') else 4
             self.cc = ActiveProgress(t=estimated_time, title=self.item_title_print, show_progress_bar=self.show_progress_bar, file=sys.stdout)
         else:
             print(self.item_title_print + ('.' * max(0, self.nL - 4 - len(self.item_title_print))), end="")
-
         self._test = test
-        # from unitgrade.unitgrade import Logger
-
         if not self.unmute:
             self._stdout = sys.stdout
             sys.stdout = io.StringIO()
@@ -238,7 +233,10 @@ def get_hints(ss):
         ss = textwrap.dedent(ss)
         ss = ss.replace('''"""''', "").strip()
         hints = ["hints:", "hint:"]
-        j = np.argmax([ss.lower().find(h) for h in hints])
+        indexes = [ss.lower().find(h) for h in hints]
+        j = np.argmax(indexes)
+        if indexes[j] == -1:
+            return None
         h = hints[j]
         ss = ss[ss.lower().find(h) + len(h) + 1:]
         ss = "\n".join([l for l in ss.split("\n") if not l.strip().startswith(":")])
@@ -295,25 +293,63 @@ class UTestCase(unittest.TestCase):
 
     def _callTearDown(self):
         self.tearDown()
+        # print("Teardown.")
         if self._with_coverage:
+            # print("with cov")
             from pathlib import Path
             from snipper import snipper_main
-            self.cov.stop()
+            try:
+                # print("Stoppping coverage...")
+                self.cov.stop()
+                # self.cov.html_report()
+                # print("Success!")
+            except Exception as e:
+                print("Something went wrong while tearing down coverage test")
+                print(e)
             data = self.cov.get_data()
             base, _, _ = self._report._import_base_relative()
+            # print("Measured coverage files", data.measured_files)
             for file in data.measured_files():
+                # print(file)
                 file = os.path.normpath(file)
                 root = Path(base)
                 child = Path(file)
+                # print("root", root, "child", child)
+                # print(child, "is in parent?", root in child.parents)
+                # print(child.parents)
+
                 if root in child.parents:
+                    # print("Reading file", child)
                     with open(child, 'r') as f:
                         s = f.read()
                     lines = s.splitlines()
                     garb = 'GARBAGE'
                     lines2 = snipper_main.censor_code(lines, keep=True)
+                    # print("\n".join(lines2))
+                    if len(lines) != len(lines2):
+                        for k in range(len(lines)):
+                            print(k, ">", lines[k], "::::::::", lines2[k])
+
+                        # print("-" * 100)
+                        # print("\n".join(lines))
+                        # print("-"*100)
+                        # print("\n".join(lines2))
+                        # print("-" * 100)
+                        print("Snipper failure; line lenghts do not agree. Exiting..")
+                        print(child, "len(lines) == len(lines2)", len(lines), len(lines2))
+                        import sys
+                        sys.exit()
+
                     assert len(lines) == len(lines2)
-                    for l in data.contexts_by_lineno(file):
+                    # print("In file ", file, "context by lineno", data.contexts_by_lineno(file))
+                    for ll in data.contexts_by_lineno(file):
+                        l = ll-1
+                        # print(l)
+                        l1 = (lines[l] + " "*1000)[:80]
+                        l2 = (lines2[l] + " "*1000)[:80]
+                        # print("l is", l, l1, " " + l2, "file", file)
                         if lines2[l].strip() == garb:
+                            # print("Got a hit at l", l)
                             rel = os.path.relpath(child, root)
                             cc = self._covcache
                             j = 0
@@ -326,7 +362,10 @@ class UTestCase(unittest.TestCase):
                             if rel not in cc:
                                 cc[rel] = {}
                             cc[rel][fun] = (l, "\n".join(comments))
+                            # print("found", rel, fun)
                             self._cache_put((self.cache_id(), 'coverage'), self._covcache)
+        # import sys
+        # sys.exit()
 
     def shortDescriptionStandard(self):
         sd = super().shortDescription()
@@ -477,11 +516,14 @@ class UTestCase(unittest.TestCase):
         else:
             print("Warning! data file not found", cfile)
 
+    # def _feedFailuresToResult(self, result, errors):
+    #     print("asdfdf")
+
     def _feedErrorsToResult(self, result, errors):
         """ Use this to show hints on test failure. """
         if not isinstance(result, UTextResult):
             er = [e for e, v in errors if v != None]
-
+            # print("Errors are", errors)
             if len(er) > 0:
                 hints = []
                 key = (self.cache_id(), 'coverage')
